@@ -95,7 +95,7 @@ public class XingJsonActivator extends AJAXModuleActivator {
             public boolean isEnabled(String capability, Session ses) throws OXException {
                 if (sCapability.equals(capability)) {
                     final ServerSession session = ServerSessionAdapter.valueOf(ses);
-                    if (session.isAnonymous()) {
+                    if (session.isAnonymous() || session.getUser().isGuest()) {
                         return false;
                     }
 
